==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_es-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Completado</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Restricción de eje...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>definir una restricción de eje entre dos objetos</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Auto-prueba...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Ejecuta una auto-prueba para comprobar si la aplicación funciona correctamente</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>Dibujar</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>Bosquejo</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Borrador</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Basado en esbozo</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primarios</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Paramétrico</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Apariencia del objeto</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Herramientas de alambre</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_es-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es-ES" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Completado</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Restricción de eje...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>definir una restricción de eje entre dos objetos</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Auto-prueba...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Ejecuta una auto-prueba para comprobar si la aplicación funciona correctamente</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>Dibujar</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>Bosquejo</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Borrador</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Basado en esbozo</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Primarios</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Paramétrico</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Apariencia del objeto</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Herramientas de alambre</translation>
    </message>
  </context>
</TS>
